@@ -8,16 +8,16 @@ use LWP::UserAgent;
 
 =head1 NAME
 
-WWW::TamperData - Replay tamper data xml files!
+WWW::TamperData - Replay tamper data xml files
 
 =head1 VERSION
 
-Version 0.02
+Version 0.05
 
 =cut
 
 # Globals
-our $VERSION = '0.02';
+our $VERSION = '0.05';
 our $AUTHOR = 'Eldar Marcussen - http://www.justanotherhacker.com';
 our $_tamperagent;
 our $_tamperxml;
@@ -61,19 +61,52 @@ This function will replay all the requests provided in the xml file in sequentia
 
 =cut
 
+#TODO: Add delay between requests
 sub replay {
     my $self = shift;
     if (ref($_tamperxml->{tdRequest}) eq 'ARRAY') {
         for my $x (0..scalar($_tamperxml->{tdRequest})) {
             $_tamperxml->{tdRequest}->[$x]->{uri} =~ s/%([0-9A-F][0-9A-F])/pack("c",hex($1))/gei;
-            my $response = $_tamperagent->get($_tamperxml->{tdRequest}->[$x]->{uri});
+            my $request = HTTP::Request->new($_tamperxml->{tdRequest}->[$x]->{tdRequestMethod} => "$_tamperxml->{tdRequest}->[$x]->{uri}");
+            my $response = $_tamperagent->get($request);
             if (!$response->is_success) {
                 croak $response->status_line;
             }
         }
+    } else {
+        $_tamperxml->{tdRequest}->{uri} =~ s/%([0-9A-F][0-9A-F])/pack("c",hex($1))/gei;
+        my $request = HTTP::Request->new($_tamperxml->{tdRequest}->{tdRequestMethod} => "$_tamperxml->{tdRequest}->{uri}");
+        my $response = $_tamperagent->get($request);
+        if (!$response->is_success) {
+            croak $response->status_line;
+        }
     }
 }
 
+=head2 request_filter
+
+Callback function that allows inspection/tampering of the uri and parameters before the request is performed.
+
+=cut
+
+sub request_filter {
+    my ($self, $callback) = @_;
+    my ($caller) = caller;
+    $self->{request_filter} = $caller.$callback;
+}
+
+=head2 response_filter
+
+Callback function that allows inspection of the response object.
+
+=cut
+
+sub response_filter {
+    my ($self, $callback) = @_;
+    my ($caller) = caller;
+    $self->{request_filter} = $caller.$callback;
+}
+
 =head1 AUTHOR
 
 Eldar Marcussen, C<< <japh at justanotherhacker.com> >>
